%%count differences between the observed paired mixture and the paired mixture expected from the distributions of the monoculture incubations at the same time point.
% we normalize the data by the mean of the medians of the monocultures taken at the last time point, to accentuate any differences in growth. I also tried log10 but that masks any differences too much.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% extract droplet data file and separate into conditions, timepoints and replicates
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear

% Get path to the current directory of this script
resultPath = matlab.desktop.editor.getActiveFilename;
fprintf('%s\n', resultPath);
% Find all indices of the '/'
slashIndices = find(resultPath == '/');
% Find the index of the 3rd '/' from the end
thirdSlashFromEndIndex = slashIndices(end-2);
% Remove the part after the 3rd '/' from the end
Currentdir = resultPath(1:thirdSlashFromEndIndex);
fprintf('%s\n', Currentdir);

% path to main folder with images
Main = strcat(Currentdir,'/Figure4&S7&S8/results_plots/')

dataset=readtable(strcat(Main,'droplet_results.csv')); %as a table

%%filter on experiments
timepoints=[];
timep=[];
timepoints=table2cell(dataset(:,1)); %to be able to filter on time point T0, T24, T48
timepoint=unique(timepoints);

for j=1:length(timepoint)

    time=find(matches(string(timepoints),timepoint{j})); %
    exp_time=dataset(time,:);


    replicates=table2cell(exp_time(:,3));
    replicate=unique(replicates);

    for z=1:length(replicate)

        ab=[]; ppm=[]; pvm=[]; pvpp=[]; empty=[];
        ab=find(matches(string(replicates),replicate{z}));

        exp_ab=exp_time(ab,:);
        ppm=find(table2array(exp_ab(:,16))==0 & table2array(exp_ab(:,19))>0); %Fluo2Sum is Ppu
        pvm=find(table2array(exp_ab(:,19))==0 & table2array(exp_ab(:,16))>0); %Fluo1Sum is PVE
        pvpp=find(table2array(exp_ab(:,16))>0 & table2array(exp_ab(:,19))>0);
        empty=find(table2array(exp_ab(:,16))==0 & table2array(exp_ab(:,19))==0);

        timep(j).rep(z).Ppu_Mono=exp_ab(ppm,:);
        timep(j).rep(z).Pve_Mono=exp_ab(pvm,:);
        timep(j).rep(z).Pve_Ppu=exp_ab(pvpp,:);
        timep(j).rep(z).Empty=exp_ab(empty,:);

    end %end loop replicate

    clearvars ab exp_ab

    timep(j).time=timepoint{j};
end %end loop time points

%%make four scatter plots to show the data

close all

figH=figure;

position=[0.1 0.4 0.2 0.2; 0.35 0.4 0.2 0.2; 0.1 0.1 0.2 0.2; 0.35 0.1 0.2 0.2];
timepoints=[0,17,24,48];

for j=1:4
    for z=1:3

        subplot('Position',position(j,:));

        data=datasample(timep(j).rep(z).Pve_Ppu,100);
        scatter(log10(data.Fluo2Sum),log10(data.Fluo1Sum),'.');
        hold on
    end

    set(gca,'FontSize',6);
    xlim([3 8]);
    ylim([3 8]);
    xlabel('log10 SW Fluo2Sum');
    ylabel('log10 L15 Fluo1Sum');
    grid on
    title(append('time = ',num2str(timepoints(j)),' h'),'FontSize',8);

end

saveas(figH, strcat(Main,'Fig4_E.pdf'),'pdf');


%look at distributions - how much is growing, how much isn't?

close all
bins=(3:0.1:7.5);
h=histogram(log10(timep(4).rep(3).Pve_Mono.Fluo1Sum),bins,'Normalization','probability')
hold on
h2=histogram(log10(timep(4).rep(3).Pve_Ppu.Fluo1Sum),bins,'Normalization','probability')

%%find the 'peaks' in all distributions

bins=(3:0.1:7.5);

for j=2:4

    for z=1:3

        h=histogram(log10(timep(j).rep(z).Pve_Mono.Fluo1Sum),bins,'Normalization','probability');
        peak_max_Pve(j,z)=power(10,bins(find(h.Values==max(h.Values))+1));

        b=histogram(log10(timep(j).rep(z).Ppu_Mono.Fluo2Sum),bins,'Normalization','probability');
        peak_max_Ppu(j,z)=power(10,bins(find(b.Values==max(b.Values))+1));

    end
end


%remove non-growing parts

thr_SW=1e5; thr_L15=power(10,5.5);

for j=2:4
    for z=1:3

        SW_Mono_red{j,z}=timep(j).rep(z).Ppu_Mono.Fluo2Sum(timep(j).rep(z).Ppu_Mono.Fluo2Sum>thr_SW);
        SW_L15_red{j,z}=timep(j).rep(z).Pve_Ppu.Fluo2Sum(timep(j).rep(z).Pve_Ppu.Fluo2Sum>thr_SW);
        L15_Mono_red{j,z}=timep(j).rep(z).Pve_Mono.Fluo1Sum(timep(j).rep(z).Pve_Mono.Fluo1Sum>thr_L15);
        L15_SW_red{j,z}=timep(j).rep(z).Pve_Ppu.Fluo1Sum(timep(j).rep(z).Pve_Ppu.Fluo1Sum>thr_L15);
        Mixed=timep(j).rep(z).Pve_Ppu((timep(j).rep(z).Pve_Ppu.Fluo1Sum>thr_L15 & timep(j).rep(z).Pve_Ppu.Fluo2Sum>thr_SW),:);
        %for later use in the simulations
        Mix{j,z}=[Mixed.Fluo2Sum,Mixed.Fluo1Sum];

    end;end

% now use these values to normalize the values at each time point

for j=2:4

    for z=1:3

        L15_Mono{j,z}=L15_Mono_red{j,z}/peak_max_Pve(j,z);
        L15_SW{j,z}=L15_SW_red{j,z}/peak_max_Pve(j,z);
        SW_Mono{j,z}=SW_Mono_red{j,z}/peak_max_Ppu(j,z);
        SW_L15{j,z}=SW_L15_red{j,z}/peak_max_Ppu(j,z);
        Mix{j,z}=[Mix{j,z}(:,1)/peak_max_Ppu(j,z) , Mix{j,z}(:,2)/peak_max_Pve(j,z)];

    end
end

%%take distribution values, median, top10 and low 10

for j=2:4
    for z=1:3

        median_SW(j,z)=median(SW_Mono{j,z});
        median_SW_L15(j,z)=median(SW_L15{j,z});
        median_L15(j,z)=median(L15_Mono{j,z});
        median_L15_SW(j,z)=median(L15_SW{j,z});
        top10_SW(j,z)=prctile(SW_Mono{j,z},90);
        top10_SW_L15(j,z)=prctile(SW_L15{j,z},90);
        top10_L15(j,z)=prctile(L15_Mono{j,z},90);
        top10_L15_SW(j,z)=prctile(L15_SW{j,z},90);
        low10_SW(j,z)=prctile(SW_Mono{j,z},10);
        low10_SW_L15(j,z)=prctile(SW_L15{j,z},10);
        low10_L15(j,z)=prctile(L15_Mono{j,z},10);
        low10_L15_SW(j,z)=prctile(L15_SW{j,z},10);

    end
end

%collect all data

m1=reshape(median_SW',[],1);
m1(1:3)=[];
m2=reshape(median_SW_L15',[],1);
m2(1:3)=[];
m3=reshape(median_L15',[],1);
m3(1:3)=[];
m4=reshape(median_L15_SW',[],1);
m4(1:3)=[];

[p1,h1,stats1] = signrank(m1, m2,'tail','left');
[p2,h2,stats1] = signrank(m3, m4,'tail','left');

%p1 = 0.0488 mono cultures have lower median than co-cultures
%p2 = 0.0020 mono cultures have lower median than co-cultures

m5=reshape(top10_SW',[],1);
m5(1:3)=[];
m6=reshape(top10_SW_L15',[],1);
m6(1:3)=[];
m7=reshape(top10_L15',[],1);
m7(1:3)=[];
m8=reshape(top10_L15_SW',[],1);
m8(1:3)=[];

[p3,h3,stats1] = signrank(m5, m6,'tail','left'); %p3 = 0.1797 - no difference
[p4,h4,stats1] = signrank(m7, m8,'tail','left'); %p4 = 0.0020 - mono cultures have lower top10 than co-cultures

m9=reshape(low10_SW',[],1);
m9(1:3)=[];
m10=reshape(low10_SW_L15',[],1);
m10(1:3)=[];
m11=reshape(low10_L15',[],1);
m11(1:3)=[];
m12=reshape(low10_L15_SW',[],1);
m12(1:3)=[];

[p5,h5,stats1] = signrank(m9, m10,'tail','right'); %p5 = 0.2129 - no difference
[p6,h6,stats1] = signrank(m11, m12,'tail','left'); %p6 = 0.0273 - mono culture lower than coculture

results6=[m11,m12];

%%count fractions

for j=2:4
    for z=1:3
        SW_Mono_top10_f(j,z)=length(SW_Mono{j,z}(SW_Mono{j,z}>top10_SW(j,z)))/length(SW_Mono{j,z});
        %with mono top10 limit as cutoff
        SW_L15_top10_f(j,z)=length(SW_L15{j,z}(SW_L15{j,z}>top10_SW(j,z)))/length(SW_L15{j,z});
        L15_Mono_top10_f(j,z)=length(L15_Mono{j,z}(L15_Mono{j,z}>top10_L15(j,z)))/length(L15_Mono{j,z});
        %with mono top10 limit as cutoff
        L15_SW_top10_f(j,z)=length(L15_SW{j,z}(L15_SW{j,z}>top10_L15(j,z)))/length(L15_SW{j,z});

        SW_Mono_low10_f(j,z)=length(SW_Mono{j,z}(SW_Mono{j,z}<low10_SW(j,z)))/length(SW_Mono{j,z});
        %with mono low10 limit as cutoff
        SW_L15_low10_f(j,z)=length(SW_L15{j,z}(SW_L15{j,z}<low10_SW(j,z)))/length(SW_L15{j,z});
        L15_Mono_low10_f(j,z)=length(L15_Mono{j,z}(L15_Mono{j,z}<low10_L15(j,z)))/length(L15_Mono{j,z});
        %with mono low10 limit as cutoff
        L15_SW_low10_f(j,z)=length(L15_SW{j,z}(L15_SW{j,z}<low10_L15(j,z)))/length(L15_SW{j,z});


    end
end

%%reshape for table

m13=reshape(SW_Mono_top10_f',[],1);
m13(1:3)=[];
m14=reshape(SW_L15_top10_f',[],1);
m14(1:3)=[];
m15=reshape(L15_Mono_top10_f',[],1);
m15(1:3)=[];
m16=reshape(L15_SW_top10_f',[],1);
m16(1:3)=[];

m17=reshape(SW_Mono_low10_f',[],1);
m17(1:3)=[];
m18=reshape(SW_L15_low10_f',[],1);
m18(1:3)=[];
m19=reshape(L15_Mono_low10_f',[],1);
m19(1:3)=[];
m20=reshape(L15_SW_low10_f',[],1);
m20(1:3)=[];

[p7,h7,stats1] = signrank(m13, m14,'tail','left'); %p7 = 0.1250 - no difference
[p8,h8,stats1] = signrank(m15, m16,'tail','left'); %p8 = 0.0020 - mono culture
[p9,h9,stats1] = signrank(m17, m18,'tail','left'); %p9 = 0.0820 - no difference
[p10,h10,stats1] = signrank(m19, m20,'tail','right'); %p10 = 0.0488 - coculture


results=[m1, m2, m3, m4, m5, m6, m7, m8, m9, m10, m11, m12, m13, m14, m15, m16, m17, m18, m19, m20];
samples=table({'T17-1','T17-2','T17-3','T24-1','T24-2','T24-3','T48-1','T48-2','T48-3'}');
t=[samples,array2table((results),'VariableNames',{'median SW_mono','median SW_L15','median L15_mono', 'median L15_SW','top10 SW_mono','top10 SW_L15','top10 L15_mono', 'top10 L15_SW','low10 SW_mono','low10 SW_L15','low10 L15_mono', 'low10 L15_SW','top10_fract SW_mono','top10_fract SW_L15','top10_fract L15_mono', 'top10_fract L15_SW','low10_fract SW_mono','low10_fract SW_L15','low10_fract L15_mono', 'low10_fract L15_SW'})];

writetable(t,strcat(Main,'distribution-counts.xlsx'));

tests=table({'median_SW/SW_L15','median_L15/L15_SW','top10_SW/SW_L15','top10_L15/L15_SW','low10_SW/SW_L15','low10_L15/L15_SW','SW/SW_L15_top10_f','L15/L15_SW_top10_f','SW/SW_L15_low10_f','L15/L15_SW_low10_f'}');
t=[];
t=[tests,array2table([p1,p2,p3,p4,p5,p6,p7,p8,p9,p10]','VariableNames',{'SignRank P-value'})];

writetable(t, strcat(Main,'distribution-counts-stats.xlsx'));


%count proportions of non-growing

for j=2:4
    for z=1:3 %replicates

        SW_non_grow(j,z)=length(timep(j).rep(z).Ppu_Mono.Fluo2Sum(timep(j).rep(z).Ppu_Mono.Fluo2Sum<thr_SW))/length(timep(2).rep(z).Ppu_Mono.Fluo2Sum); %
        L15_non_grow(j,z)=length(timep(j).rep(z).Pve_Mono.Fluo1Sum(timep(j).rep(z).Pve_Mono.Fluo1Sum<thr_L15))/length(timep(j).rep(z).Pve_Mono.Fluo1Sum); %

        SW_L15_non_grow(j,z)=length(timep(j).rep(z).Pve_Ppu.Fluo2Sum(timep(j).rep(z).Pve_Ppu.Fluo2Sum<thr_SW))/length(timep(j).rep(z).Pve_Ppu.Fluo2Sum); %0.1384
        L15_SW_non_grow(j,z)=length(timep(j).rep(z).Pve_Ppu.Fluo1Sum(timep(j).rep(z).Pve_Ppu.Fluo1Sum<thr_L15))/length(timep(j).rep(z).Pve_Ppu.Fluo1Sum); %0.1384

    end; end

m21=reshape(SW_non_grow',[],1);
m21(1:3)=[];
m22=reshape(SW_L15_non_grow',[],1);
m22(1:3)=[];
m23=reshape(L15_non_grow',[],1);
m23(1:3)=[];
m24=reshape(L15_SW_non_grow',[],1);
m24(1:3)=[];

[p11,h11,stats1] = signrank(m21, m22,'tail','left'); %p11 = 0.7520 - no difference
[p12,h12,stats1] = signrank(m23, m24,'tail','left'); %p8 = 0.2480 - no difference

results=[];
results=[m21, m22, m23, m24];
samples=table({'T17-1','T17-2','T17-3','T24-1','T24-2','T24-3','T48-1','T48-2','T48-3'}');
t=[samples,array2table((results),'VariableNames',{'SW_non_grow','SW_L15 non_grow','L15 non_grow', 'L15_SW non_grow'})];

writetable(t, strcat(Main, 'fraction-non-grow-stats.xlsx'));

%%
%%run simulations of the expected growth based on mono culture productivities
%%and compare to the actual observed fractions

clearvars -except timep SW_Mono SW_L15 L15_Mono L15_SW Mix peak_max_Ppu peak_max_Pve

for j=2:4;
    for z=1:3;

        SW=SW_Mono{j,z};
        L15=L15_Mono{j,z};

        %%use the distributions of SW and L15 alone to make a probability vector
        %select the bin range. I use different bin ranges for both to make it easier to keep track of who is who :)

        bin_range_SW=linspace(0,5,25); %1x25 double -
        bin_range_L15=linspace(0,3,33); %1x33 double

        %make the probability vectors that correspond to the grouped data

        his=histogram(SW, 'BinEdges',bin_range_SW,'Normalization','probability');
        his_counts=his.Values;

        probability_vector_SW=100*his_counts;

        his=[];his_counts=[];
        his=histogram(L15, 'BinEdges',bin_range_L15,'Normalization','probability');
        his_counts=his.Values;

        probability_vector_L15=100*his_counts;

        %% make grid to count fractions, same size as n1 - careful, n1 is in mirror to the plot

        thr=zeros(size(probability_vector_L15,2)+1,size(probability_vector_SW,2)+1);

        thr_PPUh_PVEh=thr; %both are 'high'
        thr_PPUh_PVEh(17:32,10:24)=1; %this is where the probabilities would be highest if no interaction
        thr_PPUh_PVEh=logical(thr_PPUh_PVEh);

        thr_PPUl_PVEh=thr;
        thr_PPUl_PVEh(17:32,1:9)=1; %SW is low and L15 is high
        thr_PPUl_PVEh=logical(thr_PPUl_PVEh);

        thr_PPUl_PVEl=thr; %weaker SW and L15 than expected
        thr_PPUl_PVEl(1:16,1:9)=1;
        thr_PPUl_PVEl=logical(thr_PPUl_PVEl); %the grid positions we expect to be occupied by the community


        thr_PPUh_PVEl=thr; %weaker L15 than expected
        thr_PPUh_PVEl(1:16,10:24)=1;
        thr_PPUh_PVEl=logical(thr_PPUh_PVEl);

        %vary n in datasample for the five simulations, which ideally correspond to the numbers of droplets you are analyzing in your data

        bead_sample = [300, 400, 450, 350, 397];

        for k=1:length(bead_sample);

            %make sure to empty the variables each time in the loop

            bead_SW=[]; bead_L15=[]; xy=[]; p1=[]; n1=[]; xb=[]; yb=[]; LG=[];

            bead_SW=datasample(bin_range_SW(1:end-1),bead_sample(k),'weights',probability_vector_SW);
            bead_L15=datasample(bin_range_L15(1:end-1),bead_sample(k),'weights',probability_vector_L15);

            xy=[bead_SW' bead_L15'];

            %grid count

            anchor=[0,0;max(bin_range_SW),max(bin_range_L15)];
            LG=vertcat(anchor,xy);
            nbins=[25 33];

            %% count fractions from 3D histogram

            p1=hist3(LG,nbins);
            n1=p1';
            px=arrayfun(@(x) x./length(LG),p1); %for the normalized plot

            %% make grid to count, same size as n1 - careful, n1 is in mirror to the plot


            cnt_PPUh_PVEl(k)=sum(bsxfun(@times,n1,thr_PPUh_PVEl),'all')/length(LG); %to get the proportion of droplets in this area of the grid

            cnt_PPUl_PVEh(k)=sum(bsxfun(@times,n1,thr_PPUl_PVEh),'all')/length(LG);

            cnt_PPUh_PVEh(k)=sum(bsxfun(@times,n1,thr_PPUh_PVEh),'all')/length(LG);

            cnt_PPUl_PVEl(k)=sum(bsxfun(@times,n1,thr_PPUl_PVEl),'all')/length(LG);

        end


        %%now calculate fractions from the experimental data


        xy=[]; LG=[]; p2=[]; %clear variables every time in the loop


        xy=Mix{j,z}; %combine the data, first column is SW

        %remove values outside the bin_range
        outside=find(xy(:,1)>max(bin_range_SW) | xy(:,2)>max(bin_range_L15));
        xy(outside,:)=[];

        anchor=[0,0;max(bin_range_SW),max(bin_range_L15)];
        LG=vertcat(anchor,xy);

        nbins=[25 33];
        p2=hist3(LG,nbins);
        n2=p2';
        px2=arrayfun(@(x) x./length(LG), p2);

        %%count the proportions for each fraction in the grid

        cnt_PPUh_PVEl_d=nansum(n2(thr_PPUh_PVEl))/length(LG); %use _d suffix to distinguish the experimental data
        cnt_PPUl_PVEh_d=nansum(n2(thr_PPUl_PVEh))/length(LG);
        cnt_PPUh_PVEh_d=nansum(n2(thr_PPUh_PVEh))/length(LG);
        cnt_PPUl_PVEl_d=nansum(n2(thr_PPUl_PVEl))/length(LG);

        %%compile results and save

        results{j,z}=vertcat(cnt_PPUh_PVEh,cnt_PPUh_PVEl,cnt_PPUl_PVEh, cnt_PPUl_PVEl);

        results_d{j,z}=vertcat(cnt_PPUh_PVEh_d,cnt_PPUh_PVEl_d,cnt_PPUl_PVEh_d, cnt_PPUl_PVEl_d);

    end;end

%%
close all

% Get path to the current directory of this script
resultPath = matlab.desktop.editor.getActiveFilename;
fprintf('%s\n', resultPath);
% Find all indices of the '/'
slashIndices = find(resultPath == '/');
% Find the index of the 3rd '/' from the end
thirdSlashFromEndIndex = slashIndices(end-2);
% Remove the part after the 3rd '/' from the end
Currentdir = resultPath(1:thirdSlashFromEndIndex);
fprintf('%s\n', Currentdir);

% path to main folder with images
Main = strcat(Currentdir,'/Figure4&S7&S8/results_plots/')


FigH=figure;
subplot('Position',[0.1, 0.3, 0.3, 0.4]);
px(1,32)=0.05; %to normalize the colorbar
h=pcolor(bin_range_SW(1:end),bin_range_L15(1:end),px');
set(gca,'fontsize',6)
xlim([0 5]);
ylim([0 3]);
xlabel('median-nrmz expected SW productivity');
ylabel('median-nrmz expected L15 productivity');
title('expected droplet distribution');

subplot('Position',[0.5, 0.3, 0.35, 0.4]);
px2(1,32)=0.05; %to normalize the colorbar
h=pcolor(bin_range_SW(1:end),bin_range_L15(1:end),px2');
set(gca,'fontsize',6)
colorbar
xlim([0 5]);
ylim([0 3]);
xlabel('median-nrmz observed PPU productivity');
ylabel('median-nrmz observed PVE productivity');
title('observed droplet distribution')

saveas(FigH, strcat(Main,'Fig4_F.pdf'),'pdf');

%%combine all results

fgh=vertcat(results{:}); %this is now per replicate, columns= sims, rows=fractions(T17,T24,T48) etc
tmp=vertcat(results_d{:}); %36x1

results_combined=[fgh,tmp];
replicates=[repmat({'REP1'},12,1); repmat({'REP2'},12,1); repmat({'REP3'},12,1)];
timepoints=repmat([repmat({'T17'},4,1);repmat({'T24'},4,1);repmat({'T48'},4,1)],3,1);
fractions=repmat({'SWhi_L15hi','SWhi_L15lo','SWlo_L15hi','SWlo_L15lo'}',9,1);

t=[table(replicates), table(timepoints), table(fractions),array2table(results_combined,'VariableNames',{'SIM1','SIM2','SIM3','SIM4','SIM5','OBS'})];

writetable(t, strcat(Main,'observed-expected-fractions.xlsx'));

%%stats on expected fractions

HIHI=find(matches(t.fractions,'SWhi_L15hi'));
hihi_t=t(HIHI,:);

[p,h,stats]=signrank(mean([hihi_t.SIM1,hihi_t.SIM2,hihi_t.SIM3,hihi_t.SIM4,hihi_t.SIM5],2),hihi_t.OBS,'tail','left');

%p = 0.0039

mean([hihi_t.SIM1,hihi_t.SIM2,hihi_t.SIM3,hihi_t.SIM4,hihi_t.SIM5],'all') %0.0094
mean(hihi_t.OBS); %0.0317

HILO=find(matches(t.fractions,'SWhi_L15lo'));
hilo_t=t(HILO,:);

[p,h,stats]=signrank(mean([hilo_t.SIM1,hilo_t.SIM2,hilo_t.SIM3,hilo_t.SIM4,hilo_t.SIM5],2),hilo_t.OBS,'tail','left');

%p = 0.2480

mean([hilo_t.SIM1,hilo_t.SIM2,hilo_t.SIM3,hilo_t.SIM4,hilo_t.SIM5],'all') %0.0819
mean(hilo_t.OBS); %0.0922


LOHI=find(matches(t.fractions,'SWlo_L15hi'));
lohi_t=t(LOHI,:);

[p,h,stats]=signrank(mean([lohi_t.SIM1,lohi_t.SIM2,lohi_t.SIM3,lohi_t.SIM4,lohi_t.SIM5],2),lohi_t.OBS,'tail','left'); %p = 0.0273


mean([lohi_t.SIM1,lohi_t.SIM2,lohi_t.SIM3,lohi_t.SIM4,lohi_t.SIM5],'all') %0.0900
mean(lohi_t.OBS); %0.1096


%%
LOLO=find(matches(t.fractions,'SWlo_L15lo'));
lolo_t=t(LOLO,:);

[p,h,stats]=ranksum(mean([lolo_t.SIM1,lolo_t.SIM2,lolo_t.SIM3,lolo_t.SIM4,lolo_t.SIM5],2),lolo_t.OBS,'tail','right'); %p = 0.0071

mean([lolo_t.SIM1,lolo_t.SIM2,lolo_t.SIM3,lolo_t.SIM4,lolo_t.SIM5],'all') %0.8161
mean(lolo_t.OBS); %0.7609


