%%Post processing analysis with moving interval on LN-transformed area data to calculate mu-Monod
%%
clear

% Get path to the current directory of this script
resultPath = matlab.desktop.editor.getActiveFilename;
fprintf('%s\n', resultPath);
% Find all indices of the '/'
slashIndices = find(resultPath == '/');
% Find the index of the 3rd '/' from the end
thirdSlashFromEndIndex = slashIndices(end-4);
% Remove the part after the 3rd '/' from the end
Currentdir = resultPath(1:thirdSlashFromEndIndex);
fprintf('%s\n', Currentdir);

% path to main folder with images
Main = strcat(Currentdir,'/raw_data/microplate_reader/microplate_reader_L15_SW/succinate_4mM_salicylate_1.5mM/') 

metadata=readtable(strcat(Main,'microplate_well_annotation.xlsx'),'ReadVariableNames',true);

A=readmatrix(strcat(Main,'OD_GFP_mScarletI_curves.xlsx'),'Sheet','R1_R2_R3_GFP'); %first column is time

A(:,1)=[];
annotation=readtable(strcat(Main,'OD_GFP_mScarletI_curves.xlsx'),'Sheet','R1_R2_R3_GFP','Range','B1:CG1','ReadVariableNames',false);
annotation=table2array(annotation);

%%extract mu and rsq with a gliding scale - here 5 points

w1=20; %for the first 10 hours, is 20 points
t=[30:30:w1*30]/60; %time scale in hours for the length of the table

int=5; %number of points for the floating interval

for k=1:size(A,2)
    for z=1:length(t)-int
        [r(z), m(z), b(z)]=regression(t(z:z+int),log(A(z:z+int,k))');
        %m=slope, b=intercept
    end
    best_r=find(r>0.97); %find the intervals where the rsq is above 0.97
    best_m=mean(m(best_r)); %take the mean mu for those intervals
    best_r_m=mean(r(best_r)); %take the mean rsq for those intervals

    pos.mu(k)=best_m; %to collect all data
    pos.rsq(k)=best_r_m;
    pos.net_area(k)=A(end,k)-A(1,k);

end %end loop



L15=({'A1','B1','C1','D1','E1','F1','G1','A5','B5','C5','D5','E5','F5','G5','A9','B9','C9','D9','E9','F9','G9'});
idx=find(matches(annotation,L15));
L15_mu=pos.mu(idx);
SW=({'A2','B2','C2','D2','E2','F2','G2','A6','B6','C6','D6','E6','F6','G6','A10','B10','C10','D10','E10','F10','G10'});
idxv=find(matches(annotation,SW));
SW_mu=pos.mu(idxv);
mix=({'A3','B3','C3','D3','E3','F3','G3','A7','B7','C7','D7','E7','F7','G7','A11','B11','C11','D11','E11','F11','G11'});
idxm=find(matches(annotation,mix));
SW_L15_mu=pos.mu(idxm);


%%plot ln-transformed GFP per well over time (if needed)

close all
T=[30:30:size(A,1)*30]/60; %time scale in hours for the length of the table
%plot(T,log(A)); %for the whole table
PVE_sub=A(:,idxv); %subset of e.g., only PVE growth data
plot(T,log(PVE_sub));


%% fit log and lag data

addpath(strcat(Currentdir,'additional_matlab_function_scripts/'))

T=[30:30:size(A,1)*30]/60; %time scale in hours for the length of the table

for k=1:size(A,2)

    Time_step=T;
    Evol_mass=A(:,k);
    aa=min(find(Evol_mass>145)); %value in the blanc
    if ~isempty(aa)

        AA=Evol_mass(aa);
        Evol_mass(Evol_mass<AA)=145;
        lag_time=0;

        x0 = [1, max(Evol_mass), Evol_mass(1), lag_time];
        opts_1 = odeset('RelTol',1e-9,'AbsTol',1e-10);
        fun_Logistic = @(x, Time_step) x(2)./(1 + (x(2) - x(3))/x(3).*exp(-x(1)*Time_step));

        [pars, ~] = fminsearch(@(x) -logLikelihood(Evol_mass, 1e02, Time_step, 0, x(1), x(4), x(2), opts_1),...
            x0,...%Initial guess
            optimset('MaxFunEvals', 20000));

        sol = ode45(@(t,x) dfun(t, x, Evol_mass(1), 0, pars(1), pars(4), pars(2)), [0 max(Time_step)], Evol_mass(1), opts_1);
        x_est = deval(sol, Time_step);

        time_init(k)=pars(4);
        mu_log(k)=pars(1);


        pos.time_init=time_init;
        pos.mu_log=mu_log;

    else
        time_init(k)=NaN;
        mu_log(k)=NaN;

        pos.time_init=time_init; %fitted lag time (h)
        pos.mu_log=mu_log; %fitted logaritmic growth rate - to compare to mu_monod; multiply by log(2)


    end
end %end fitting loop

%%results
SW_mu=[0.196506572067581	0.242023140121044	0.220608670081966	0.187769617411990	0.238276494298487	0.203384497132179	0.170149750063567	0.243704160583389	0.207961800096735	0.209601685226728	0.207719400109872	0.190986659497067	0.213206049134290	0.193180263268759	0.205603341045018	0.226482321772981	0.259207271471801	0.218322529359883	0.213619459551464	0.206400143972136	0.241728862493359];
SW_L15_mu=[0.148662917357482	0.151107606101374	0.152089068146996	0.169962526669209	0.159971905362229	0.169895396340635	0.161495095554355	0.135103429206740	0.185521804505027	0.157472664302920	0.145662604308672	0.166879181961290	0.159819839555092	0.141961573064150	0.179028259706879	0.143259214108791	0.168819455224239	0.169695604616305	0.165495004667406	0.149426713829269	0.166474085744321];

%%time to first doubling is fitted lag time plus the inverse of the mu_log, corrected for ln(2)

lag=[pos.time_init(:)];
mu_log=[pos.mu_log(:)];
lag(lag<-0.01)=0.01;

time_doubling=lag+1./mu_log./log(2);
time_doubling=time_doubling';

SW_time_init=pos.time_init(idxv);
%
% 0.00395345433500097	0.00174104406779283	0.00175275838553490	0.000331228941758564	-0.00100356339868243	0.00322551975434664	0.00374254200439601	0.000109413631376801	0.00147233157180271	-4.44300221145358e-05	0.00398762002259895	0.000172155514459333	0.00216131429313856	0.00311248601504705	0.000360260294775619	0.00355219432944387	0.000267088917064960	0.00369131341044238	0.00240345822722079	0.00179595592774888	0.00675169535937400
%
SW_mu_log=pos.mu_log(idxv);
%
% 0.233070327494898	0.231074778363858	0.232914849966847	0.235857681981012	0.228883738557145	0.228976698929662	0.224921376857353	0.227608634157520	0.224396037211877	0.231278060031484	0.222139658315708	0.212511685811706	0.230880175757751	0.216258992134122	0.224291298540353	0.225963176289152	0.234101206904876	0.223039220371656	0.224245852421886	0.228920359954697	0.219675302381668
%
SW_L15_time_init=pos.time_init(idxm);
%
% 0.00509334567355052	0.00484403470304127	0.00906984070194205	0.00469183457378545	0.00231780199164459	0.00383843403171243	0.00397672115659441	0.000822565534666237	0.00307274964737030	0.00169870160476174	0.00449528594416391	-0.000843589583047652	0.00391185013925586	0.00465948789189917	0.00313903869477432	0.00584219305884435	-0.00178175046574794	0.00791133373917324	0.00215516361391025	0.00835265828603036	0.00877462427225042
%

SW_td=time_doubling(idxv);
%
SW_td=[6.19390932042673	6.24515303002347	6.19584060248098	6.11713450103154	6.30217485365942	6.30384496108945	6.41796186186891	6.33859936691902	6.43070815415791	6.23787991391508	6.49852826993476	6.78895196015659	6.25083570200972	6.67425724005246	6.43259838222712	6.38819886367361	6.16296509446465	6.47203817404313	6.43594515056025	6.30396602579166	6.57414923731153];
%
SW_L15_td=time_doubling(idxm);
%
SW_td=[7.18229688637684	7.18593033678396	7.21072013811063	7.35654521686459	7.08557555495457	6.91606991484253	7.38857346069127	7.28926649955415	7.34325718315377	7.17529095786178	7.53674887777131	6.96869203021522	7.27007966918416	7.21785497910835	6.96986115831840	7.07504353707207	7.12444925981989	7.09941673141583	7.42562137586072	7.28477179306391	7.32172192687856];



%% repeat for the mCherry channel

clearvars -except SW_mu SW_td SW_L15_td SW_L15_mu Currentdir Main

annotation=readtable(strcat(Main,'OD_GFP_mScarletI_curves.xlsx'),'Sheet','R1_R2_R3_mScarletI','Range','B1:CG1','ReadVariableNames',false);
annotation=table2array(annotation);

A=readmatrix(strcat(Main,'OD_GFP_mScarletI_curves.xlsx'),'Sheet','R1_R2_R3_mScarletI'); %first column is time

A(:,1)=[];

%%extract mu and rsq with a gliding scale - here 10 points

w1=20; %for the first 10 hours, is 20 points
t=[30:30:w1*30]/60; %time scale in hours for the length of the table

int=5; %number of points for the floating interval

for k=1:size(A,2)
    for z=1:length(t)-int
        [r(z), m(z), b(z)]=regression(t(z:z+int),log(A(z:z+int,k))');
        %m=slope, b=intercept
    end
    best_r=find(r>0.97); %find the intervals where the rsq is above 0.99
    best_m=mean(m(best_r)); %take the mean mu for those intervals
    best_r_m=mean(r(best_r)); %take the mean rsq for those intervals

    pos.mu(k)=best_m; %to collect all data
    pos.rsq(k)=best_r_m;
    pos.net_area(k)=A(end,k)-A(1,k);

end %end loop



L15=({'A1','B1','C1','D1','E1','F1','G1','A5','B5','C5','D5','E5','F5','G5','A9','B9','C9','D9','E9','F9','G9'});
idx=find(matches(annotation,L15));
L15_mu=pos.mu(idx);
SW=({'A2','B2','C2','D2','E2','F2','G2','A6','B6','C6','D6','E6','F6','G6','A10','B10','C10','D10','E10','F10','G10'});
idxv=find(matches(annotation,SW));
SW_mu=pos.mu(idxv);
mix=({'A3','B3','C3','D3','E3','F3','G3','A7','B7','C7','D7','E7','F7','G7','A11','B11','C11','D11','E11','F11','G11'});
idxm=find(matches(annotation,mix));
L15_SW_mu=pos.mu(idxm);




%%plot ln-transformed OD per well over time (if needed)

close all
T=[30:30:size(A,1)*30]/60; %time scale in hours for the length of the table
plot(T,log(A));


%% fit log and lag data


for k=1:size(A,2)


    Time_step=T;
    Evol_mass=A(:,k);
    aa=min(find(Evol_mass>100)); %value in the blanc
    if ~isempty(aa)

        AA=Evol_mass(aa);
        Evol_mass(Evol_mass<AA)=100;
        lag_time=0;

        x0 = [1, max(Evol_mass), Evol_mass(1), lag_time];
        opts_1 = odeset('RelTol',1e-9,'AbsTol',1e-10);
        fun_Logistic = @(x, Time_step) x(2)./(1 + (x(2) - x(3))/x(3).*exp(-x(1)*Time_step));

        [pars, ~] = fminsearch(@(x) -logLikelihood(Evol_mass, 1e02, Time_step, 0, x(1), x(4), x(2), opts_1),...
            x0,...%Initial guess
            optimset('MaxFunEvals', 20000));

        sol = ode45(@(t,x) dfun(t, x, Evol_mass(1), 0, pars(1), pars(4), pars(2)), [0 max(Time_step)], Evol_mass(1), opts_1);
        x_est = deval(sol, Time_step);

        time_init(k)=pars(4);
        mu_log(k)=pars(1);


        pos.time_init=time_init;
        pos.mu_log=mu_log;

    else
        time_init(k)=NaN;
        mu_log(k)=NaN;

        pos.time_init=time_init; %fitted lag time (h)
        pos.mu_log=mu_log; %fitted logaritmic growth rate


    end
end %end fitting loop

%%results

L15_mu=[0.292192807912196	0.284884131369762	0.285401530389913	0.269523922031339	0.255067889912759	0.280133917398161	0.278027857299514	0.261587848382891	0.289698001448484	0.297757919223084	0.274930466198553	0.300476857211621	0.260170848849983	0.262807624236673	0.308274968345321	0.314696475455994	0.259742579076358	0.290314738181389	0.304687404200259	0.281366863177236	0.220256539098665];

L15_SW_mu=[0.251080070180545	0.284301882831442	0.306093864768083	0.251096525298927	0.272555667626527	0.323391166875278	0.233903983747736	0.275014379869006	0.276193618002903	0.224938481486210	0.278143413344791	0.283414297822187	0.210189756310215	0.281203163084937	0.288149696703461	0.213267360911476	0.283345821179907	0.251163884701333	0.272878437079549	0.270389478392683	0.276787459711034];
SW_mu=[NaN	NaN	NaN	NaN	NaN	NaN	NaN];

lag=[pos.time_init(:)];
mu_log=[pos.mu_log(:)];
lag(lag<-0.01)=0.01;

time_doubling=lag+1./mu_log./log(2);
time_doubling=time_doubling';

L15_time_init=pos.time_init(idx);
%%
% -0.000975307578485379	-0.00147277245073465	-0.00110239891320686	-0.00100712018613841	-0.000331598661825158	-0.00135036771808378	-0.000922014959795572	-0.000117523771290835	0.000455057945564667	-0.00101063205377959	-0.00122801410878932	-0.000697508174049282	-0.000696113502436731	-0.000343259437132311	-0.000715979389963031	0.000248958078469416	-0.00116673510891484	-0.000716748478926977	-0.000364046488935326	-0.000380371514013820	-1.95627113081574e-05
%%
L15_mu_log=pos.mu_log(idx);
%%
% 0.237664150531747	0.239961083389420	0.256421349978945	0.236421624532819	0.232724922351061	0.270475160237425	0.229325865271780	0.259862580252809	0.264216507753327	0.235724157528459	0.254746204717103	0.248037272904902	0.235189919976221	0.259985225381099	0.261577565041128	0.264423083344532	0.251338391053310	0.250538729397005	0.277620120650189	0.245991688189662	0.266404965786525%%
%%
L15_SW_time_init=pos.time_init(idxm);
%%
% 0.000170031695058057	-0.000390998605531929	0.000489134041409384	-0.00117301655122635	0.000137047237003996	-0.000489461327141692	-0.000237734774715780	-0.00160193063709869	-0.00126727001226300	-0.00173794915212848	0.000824870948880277	-0.00225842243289455	0.00141979815491815	-0.000845193468011164	-0.00148049875670763	0.000128700767159032	-0.00156236625921481	-0.00392434128024167	-0.00179166507339070	-0.000497973080830723	-9.08598149407194e-05
%%
L15_td=time_doubling(idx);
%% in h
L15_td=[6.06933457155597	6.01073145879827	5.62516484056364	6.10120558450957	6.19881126199272	5.33257767071086	6.29010424664043	5.55164387059886	5.46073100041570	6.11925746441736	5.66203610592426	5.81574702853917	6.13347426690685	5.54879915346033	5.51464632112740	5.45625916203330	5.73888369985611	5.75765459938107	5.19628754169623	5.86443177521441	5.41540141726030];
%%
%%
L15_SW_td=time_doubling(idxm);
%%
L15_SW_td=[5.65139535904238	5.31221321064999	5.47056173074365	5.46276903693252	5.58556249464544	5.41529022210080	5.68112215429895	5.49027691435687	5.27024330237913	5.35194430086851	5.56031263567767	5.46324094523541	5.40369107677410	5.28923489797314	5.45853693027096	5.45383867474673	5.39881335231550	5.40736802116845	5.83743430772092	5.49040693513800	5.57806432832581];


SW_mu=[0.196506572067581	0.242023140121044	0.220608670081966	0.187769617411990	0.238276494298487	0.203384497132179	0.170149750063567	0.243704160583389	0.207961800096735	0.209601685226728	0.207719400109872	0.190986659497067	0.213206049134290	0.193180263268759	0.205603341045018	0.226482321772981	0.259207271471801	0.218322529359883	0.213619459551464	0.206400143972136	0.241728862493359];
SW_L15_mu=[0.148662917357482	0.151107606101374	0.152089068146996	0.169962526669209	0.159971905362229	0.169895396340635	0.161495095554355	0.135103429206740	0.185521804505027	0.157472664302920	0.145662604308672	0.166879181961290	0.159819839555092	0.141961573064150	0.179028259706879	0.143259214108791	0.168819455224239	0.169695604616305	0.165495004667406	0.149426713829269	0.166474085744321];


%% Stat test

% separate mu_max per biological replicate
SW_mu_r1 = SW_mu(1:7);
SW_mu_r2 = SW_mu(8:14);
SW_mu_r3 = SW_mu(15:21);
mean_SW_mu = [mean(SW_mu_r1), mean(SW_mu_r2), mean(SW_mu_r3)];
SW_L15_mu_r1 = SW_L15_mu(1:7);
SW_L15_mu_r2 = SW_L15_mu(8:14);
SW_L15_mu_r3 = SW_L15_mu(15:21);
mean_SW_L15_mu = [mean(SW_L15_mu_r1), mean(SW_L15_mu_r2), mean(SW_L15_mu_r3)];

L15_mu_r1 = L15_mu(1:7);
L15_mu_r2 = L15_mu(8:14);
L15_mu_r3 = L15_mu(15:21);
mean_L15_mu = [mean(L15_mu_r1), mean(L15_mu_r2), mean(L15_mu_r3)];
L15_SW_mu_r1 = L15_SW_mu(1:7);
L15_SW_mu_r2 = L15_SW_mu(8:14);
L15_SW_mu_r3 = L15_SW_mu(15:21);
mean_L15_SW_mu = [mean(L15_SW_mu_r1), mean(L15_SW_mu_r2), mean(L15_SW_mu_r3)];

% wilcoxon ranksum test (median comparison)
p_sw1 = ranksum(SW_mu_r1, SW_L15_mu_r1)
p_sw2 = ranksum(SW_mu_r2, SW_L15_mu_r2)
p_sw3 = ranksum(SW_mu_r3, SW_L15_mu_r3)
p_sw_mean = ranksum(mean_SW_mu, mean_SW_L15_mu)

p_l15_1 = ranksum(L15_mu_r1, L15_SW_mu_r1)
p_l15_2 = ranksum(L15_mu_r2, L15_SW_mu_r2)
p_l15_3 = ranksum(L15_mu_r3, L15_SW_mu_r3)
p_l15_mean = ranksum(mean_L15_mu, mean_L15_SW_mu)



%% making boxplots of mu and time to first doubling.

L15=[L15_mu; L15_SW_mu]';
L15_r1=[L15_mu_r1; L15_SW_mu_r1]';
L15_r2=[L15_mu_r2; L15_SW_mu_r2]';
L15_r3=[L15_mu_r3; L15_SW_mu_r3]';

SW=[SW_mu; SW_L15_mu]';
SW_r1=[SW_mu_r1; SW_L15_mu_r1]';
SW_r2=[SW_mu_r2; SW_L15_mu_r2]';
SW_r3=[SW_mu_r3; SW_L15_mu_r3]';

% x=ones(21,1);
x=ones(7,1);
x2=2*x;

jitterAmount=0.3;
sz=15;

close all
FigH=figure;
posvector=[0.1, 0.05, 0.15, 0.25];

subplot('Position',posvector);
boxplot(L15_r1,'Widths',0.8);
hold on
jitterValues=2*(rand(size(x))-0.5)*jitterAmount;
scatter((x+jitterValues), L15_mu_r1,sz,'m','filled');
scatter((x2+jitterValues), L15_SW_mu_r1, sz,'g','filled');
ylim([0 0.5]);
grid on
title('Pseudomonas L15 - R1');
ylabel('Fluo signal growth rate (h-1)','FontSize',7);

posvector2=[0.4, 0.05, 0.15, 0.25];

subplot('Position',posvector2);
boxplot(SW_r1,'Widths',0.8);
hold on
jitterValues=2*(rand(size(x))-0.5)*jitterAmount;
scatter((x+jitterValues), SW_mu_r1,sz,'m','filled');
scatter((x2+jitterValues), SW_L15_mu_r1, sz,'g','filled');
ylim([0 0.5]);
grid on
title('Sphingomonas - R1')
ylabel('Fluo signal growth rate (h-1)','FontSize',7)

posvector=[0.1, 0.37, 0.15, 0.25];

subplot('Position',posvector);
boxplot(L15_r2,'Widths',0.8);
hold on
jitterValues=2*(rand(size(x))-0.5)*jitterAmount;
scatter((x+jitterValues), L15_mu_r2,sz,'m','filled');
scatter((x2+jitterValues), L15_SW_mu_r2, sz,'g','filled');
ylim([0 0.5]);
grid on
title('Pseudomonas L15 - R2');
ylabel('Fluo signal growth rate (h-1)','FontSize',7);

posvector2=[0.4, 0.37, 0.15, 0.25];

subplot('Position',posvector2);
boxplot(SW_r2,'Widths',0.8);
hold on
jitterValues=2*(rand(size(x))-0.5)*jitterAmount;
scatter((x+jitterValues), SW_mu_r2,sz,'m','filled');
scatter((x2+jitterValues), SW_L15_mu_r2, sz,'g','filled');
ylim([0 0.5]);
grid on
title('Sphingomonas - R2')
ylabel('Fluo signal growth rate (h-1)','FontSize',7)

posvector=[0.1, 0.69, 0.15, 0.25];

subplot('Position',posvector);
boxplot(L15_r3,'Widths',0.8);
hold on
jitterValues=2*(rand(size(x))-0.5)*jitterAmount;
scatter((x+jitterValues), L15_mu_r3,sz,'m','filled');
scatter((x2+jitterValues), L15_SW_mu_r3, sz,'g','filled');
ylim([0 0.5]);
grid on
title('Pseudomonas L15 - R3');
ylabel('Fluo signal growth rate (h-1)','FontSize',7);

posvector2=[0.4, 0.69, 0.15, 0.25];

subplot('Position',posvector2);
boxplot(SW_r3,'Widths',0.8);
hold on
jitterValues=2*(rand(size(x))-0.5)*jitterAmount;
scatter((x+jitterValues), SW_mu_r3,sz,'m','filled');
scatter((x2+jitterValues), SW_L15_mu_r3, sz,'g','filled');
ylim([0 0.5]);
grid on
title('Sphingomonas - R3')
ylabel('Fluo signal growth rate (h-1)','FontSize',7)


filename= strcat(Currentdir, '/Figure4&S7&S8/results_plots/Fig4_B.pdf')
saveas(FigH, filename, 'pdf');


