


# Post processing
droplet_plate <- fc_table %>% 
  separate(Sample, c('Culture', 'Condition','BioRep', 'TechRep','FCcountingRep','DilutionFactor')) %>% 
  filter(Culture == 'plate', preserve = TRUE) %>% 
  mutate(NumberSpecies = case_when(Condition == "SW"|Condition == "L15" ~ "mono" , Condition == "mix" ~ "mix" )) %>%
  mutate(VolumeAnalysed_µl = 20) # add a variable for the volume analysed in flow cytometry (µl) - 20µl for most of the wells
droplet_plate$DilutionFactor <- as.numeric(droplet_plate$DilutionFactor)

# transform wide data frame into a long data frame (around flow cytometry channels)
droplet_plate_long <- droplet_plate %>% 
  pivot_longer(cols=c(mCherry.Count, GFP.Count), names_to = "channel", values_to = "counts")
droplet_plate_long$channel[droplet_plate_long$channel == 'mCherry.Count'] <- 'mCherry'
droplet_plate_long$channel[droplet_plate_long$channel == 'GFP.Count'] <- 'GFP'

# Cell concentrations in fused droplets
# droplet_cell_concentration <- droplet_plate_long %>% 
#   filter(Culture == 'droplet')  %>% 
#   mutate(CellConcentration = case_when(
#     # SW (gfp channel) - R1
#     BioRep== 'R1' &Condition=='SW' &channel=='GFP'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPP1),
#     BioRep== 'R1' &Condition=='L15' &channel=='GFP'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80),
#     BioRep== 'R1' &Condition=='media' &channel=='GFP'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80),
#     BioRep== 'R1' &Condition=='mix' &channel=='GFP'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPPmix1),
#     # R2
#     BioRep== 'R2' &Condition=='SW' &channel=='GFP'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPP2),
#     BioRep== 'R2' &Condition=='L15' &channel=='GFP'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80),
#     BioRep== 'R2' &Condition=='media' &channel=='GFP'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80),
#     BioRep== 'R2' &Condition=='mix' &channel=='GFP'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPPmix2),
#     #R3
#     BioRep== 'R3' &Condition=='SW' &channel=='GFP'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPP3),
#     BioRep== 'R3' &Condition=='L15' &channel=='GFP'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80),
#     BioRep== 'R3' &Condition=='media' &channel=='GFP'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80),
#     BioRep== 'R3' &Condition=='mix' &channel=='GFP'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPPmix3),
    
    
    #250 = vol PBS in tube 
    #80 = initial vol droplets
    
  #   # L15 (mCherry channel) - R1
  #   BioRep== 'R1' &Condition=='SW' &channel=='mCherry'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80),
  #   BioRep== 'R1' &Condition=='media' &channel=='mCherry'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80),
  #   BioRep== 'R1' &Condition=='L15' &channel=='mCherry'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPV1),
  #   BioRep== 'R1' &Condition=='mix' &channel=='mCherry'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPVmix1),
  #   # R2
  #   BioRep== 'R2' &Condition=='SW' &channel=='mCherry'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80),
  #   BioRep== 'R2' &Condition=='media' &channel=='mCherry'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80),
  #   BioRep== 'R2' &Condition=='L15' &channel=='mCherry'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPV2),
  #   BioRep== 'R2' &Condition=='mix' &channel=='mCherry'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPVmix2),
  #   # R3
  #   BioRep== 'R3' &Condition=='SW' &channel=='mCherry'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80),
  #   BioRep== 'R3' &Condition=='media' &channel=='mCherry'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80),
  #   BioRep== 'R3' &Condition=='L15' &channel=='mCherry'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPV3),
  #   BioRep== 'R3' &Condition=='mix' &channel=='mCherry'~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)*((250+80)/80)*(1/ratio_non_emptyPVmix3)
  # ))
# in previous lines: adjust the concentration of L15 and SW based on the proportion of non empty droplets measured from droplets images of all replicates


# ### Calculate and subtract average noise signal detected in empty droplets controls
# droplet_cell_conc_filt <- droplet_cell_concentration
# # remove mCherry events (L15) noise
# droplet_cell_conc_filt$CellConcentration[droplet_cell_conc_filt$channel == 'mCherry'] <- droplet_cell_conc_filt$CellConcentration[droplet_cell_conc_filt$channel == 'mCherry'] - mean(droplet_cell_conc_filt$CellConcentration[droplet_cell_conc_filt$Condition == 'media' & droplet_cell_conc_filt$channel =='mCherry']) 
# # remove GFP events (SW) noise
# droplet_cell_conc_filt$CellConcentration[droplet_cell_conc_filt$channel == 'GFP'] <- droplet_cell_conc_filt$CellConcentration[droplet_cell_conc_filt$channel == 'GFP'] - mean(droplet_cell_conc_filt$CellConcentration[droplet_cell_conc_filt$Condition == 'media' & droplet_cell_conc_filt$channel == 'GFP']) 
# # set negative values to 0
# droplet_cell_conc_filt$CellConcentration[droplet_cell_conc_filt$CellConcentration < 0] <- 0


### same for plate samples
plate_cell_concentration <- droplet_plate_long %>% 
  filter(Culture == 'plate') %>% 
  mutate(CellConcentration = case_when(
    # SW (GFP channel)
    channel=='GFP' ~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor), 
    # L15 (mCherry channel)
    channel=='mCherry' ~ (counts/VolumeAnalysed_µl)*2*1000*(10^DilutionFactor)))

### Calculate and subtract average noise signal detected in empty droplets controls 
plate_cell_conc_filt <- plate_cell_concentration
# remove mCherry events (PV) noise
plate_cell_conc_filt$CellConcentration[plate_cell_conc_filt$channel == 'mCherry'] <- plate_cell_conc_filt$CellConcentration[plate_cell_conc_filt$channel == 'mCherry'] - mean(plate_cell_conc_filt$CellConcentration[plate_cell_conc_filt$Condition == 'media' & plate_cell_conc_filt$channel == 'mCherry'])
# remove GFP events (PP) noise
plate_cell_conc_filt$CellConcentration[plate_cell_conc_filt$channel == 'GFP'] <- plate_cell_conc_filt$CellConcentration[plate_cell_conc_filt$channel == 'GFP'] - mean(plate_cell_conc_filt$CellConcentration[plate_cell_conc_filt$Condition == 'media' & plate_cell_conc_filt$channel == 'GFP']) 
# set negative values to 0
plate_cell_conc_filt$CellConcentration[plate_cell_conc_filt$CellConcentration < 0] <- 0

# Concatenate droplets and plates cell concentration tables
cell_conc <- plate_cell_conc_filt
